summaryrefslogtreecommitdiff
path: root/examples
diff options
context:
space:
mode:
authorelie <elie>2013-01-05 20:44:46 +0000
committerelie <elie>2013-01-05 20:44:46 +0000
commit27251bdf77c3fabbc8648f0c49a246d170053f98 (patch)
treeebd028d9e687af295dbfb16e4be759cd786997cd /examples
parentd57efeb1a8a0df43f64d35451eced0b57b9900ca (diff)
downloadpysnmp-27251bdf77c3fabbc8648f0c49a246d170053f98.tar.gz
converted into usr-md5-none for interoperability with other examples
Diffstat (limited to 'examples')
-rw-r--r--examples/v3arch/oneliner/manager/cmdgen/set-v3-with-custom-contextengineid-and-contextname.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/v3arch/oneliner/manager/cmdgen/set-v3-with-custom-contextengineid-and-contextname.py b/examples/v3arch/oneliner/manager/cmdgen/set-v3-with-custom-contextengineid-and-contextname.py
index 71e49d1..8acbe7a 100644
--- a/examples/v3arch/oneliner/manager/cmdgen/set-v3-with-custom-contextengineid-and-contextname.py
+++ b/examples/v3arch/oneliner/manager/cmdgen/set-v3-with-custom-contextengineid-and-contextname.py
@@ -3,7 +3,7 @@
#
# Send SNMP SET request using the following options:
#
# * with SNMPv3 with user 'usr-none-none', no auth and no privacy protocols
# * over IPv4/UDP
# * to an Agent at localhost:161
# * addressing particular set of Managed Objects at remote SNMP Engine by:
@@ -17,7 +17,7 @@ from pysnmp.proto import rfc1902
cmdGen = cmdgen.CommandGenerator()
errorIndication, errorStatus, errorIndex, varBinds = cmdGen.setCmd(
- cmdgen.UsmUserData('usr-none-none'),
+ cmdgen.UsmUserData('usr-md5-none', 'authkey1'),
cmdgen.UdpTransportTarget(('localhost', 161)),
(cmdgen.MibVariable('SNMPv2-MIB', 'sysName', 0), 'new system name'),
contextEngineId=rfc1902.OctetString(hexValue='8000000001020304'),
@@ -3,7 +3,7 @@
# Send SNMP SET request using the following options:
#
-# * with SNMPv3 with user 'usr-none-none', no auth and no privacy protocols
+# * with SNMPv3 with user 'usr-md5-none', MD5 auth and no privacy protocols
# * over IPv4/UDP
# * to an Agent at localhost:161